import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
var _jsxFileName = "C:\\Dev\\20_gsoft\\sg-orbit\\packages\\react-components\\components\\date-range-picker\\src\\date-range-picker.jsx";
import React from "react";
import "react-dates/initialize";
import "react-dates/lib/css/_datepicker.css";
import { ANCHOR_LEFT, ANCHOR_RIGHT } from "react-dates/lib/constants";
import { ArgumentError, AutoControlledPureComponent, KEYS, getAutoControlledStateFromProps } from "@orbit-ui/react-components-shared";
import { ArrowIcon, ClearIcon, InputCalendarIcon, PresetsCalendarIcon } from "@orbit-ui/icons";
import { DateRangePickerButtons } from "./date-range-picker-buttons";
import { DateRangePickerCalendar } from "./date-range-picker-calendar";
import { DateRangePickerInput } from "./date-range-picker-input";
import { DateRangePickerPresets } from "./date-range-picker-presets";
import { FadeIn } from "./fade-in";
import { PRESET_SHAPE } from "./presets";
import { Popup } from "@orbit-ui/react-popup";
import { arrayOf, bool, func, node, object, oneOf, shape, string } from "prop-types";
import { cloneElement, createRef } from "react";
import { isNil } from "lodash";
export class DateRangePicker extends AutoControlledPureComponent {
  constructor() {
    super(...arguments);

    _defineProperty(this, "state", {
      startDate: null,
      endDate: null,
      selectedStartDate: null,
      selectedEndDate: null,
      selectedPresetName: null,
      open: false
    });

    _defineProperty(this, "_containerRef", createRef());

    _defineProperty(this, "handleInputClick", event => {
      const {
        open
      } = this.state;

      if (!open) {
        this.toggleCalendarVisibility(event);
      }
    });

    _defineProperty(this, "handleInputClear", event => {
      const {
        onDatesChange
      } = this.props;
      this.trySetAutoControlledStateValue({
        startDate: null
      });
      this.trySetAutoControlledStateValue({
        endDate: null
      });
      this.setState({
        selectedStartDate: null,
        selectedEndDate: null,
        selectedPresetName: null
      });
      onDatesChange(event, null, null, null, this.props);
    });

    _defineProperty(this, "handleInputKeyDown", event => {
      const key = event.keyCode;

      if (key === KEYS.space || key === KEYS.enter) {
        if (key === KEYS.space) {
          event.preventDefault();
        }

        this.toggleCalendarVisibility(event);
      }
    });

    _defineProperty(this, "handlePopupClose", event => {
      const {
        startDate,
        endDate
      } = this.state;
      this.setState({
        selectedStartDate: startDate,
        selectedEndDate: endDate,
        selectedPresetName: null
      });
      this.toggleCalendarVisibility(event);
    });

    _defineProperty(this, "handleCalendarDatesChange", (startDate, endDate, presetName) => {
      this.setState({
        selectedStartDate: startDate,
        selectedEndDate: endDate,
        selectedPresetName: presetName
      });
    });

    _defineProperty(this, "handleCalendarApply", event => {
      const {
        onDatesChange
      } = this.props;
      const {
        selectedStartDate,
        selectedEndDate,
        selectedPresetName
      } = this.state;
      this.toggleCalendarVisibility(event);
      this.trySetAutoControlledStateValue({
        startDate: selectedStartDate
      });
      this.trySetAutoControlledStateValue({
        endDate: selectedEndDate
      });
      onDatesChange(event, selectedStartDate, selectedEndDate, selectedPresetName, this.props);
    });
  }

  componentDidMount() {
    const {
      minDate,
      maxDate
    } = this.props;

    if (!isNil(minDate) && !isNil(maxDate)) {
      if (minDate.isSameOrAfter(maxDate)) {
        throw new ArgumentError("DateRangePicker - \"minDate\" must be before \"maxDate\".");
      }
    }
  }

  static getDerivedStateFromProps(props, state) {
    return getAutoControlledStateFromProps(props, state, DateRangePicker.autoControlledProps, (_ref) => {
      let {
        startDate,
        endDate
      } = _ref;
      return {
        selectedStartDate: startDate,
        selectedEndDate: endDate
      };
    });
  }

  toggleCalendarVisibility(event) {
    const {
      onVisibilityChange
    } = this.props;
    const {
      open
    } = this.state;
    this.trySetAutoControlledStateValue({
      open: !open
    });

    if (!isNil(onVisibilityChange)) {
      onVisibilityChange(event, !open, this.props);
    }
  }

  getAnchorDirectionProps() {
    const {
      anchorDirection
    } = this.props;
    const props = {};

    if (anchorDirection === ANCHOR_LEFT) {
      props.left = "0";
    } else {
      props.right = "0";
    }

    return props;
  }

  getCssClasses() {
    const {
      className
    } = this.props;
    const defaultClasses = "relative";
    return isNil(className) ? defaultClasses : "".concat(defaultClasses, " ").concat(className);
  }

  renderInput() {
    const {
      input,
      inputIcon,
      inputClearIcon,
      placeholder,
      rangeFormat,
      dateFormat,
      disabled
    } = this.props;
    const {
      selectedStartDate,
      selectedEndDate,
      open
    } = this.state;
    return cloneElement(input, {
      startDate: selectedStartDate,
      endDate: selectedEndDate,
      onClick: this.handleInputClick,
      onClear: this.handleInputClear,
      onKeyDown: this.handleInputKeyDown,
      placeholder,
      rangeFormat,
      dateFormat,
      icon: inputIcon,
      clearIcon: inputClearIcon,
      disabled: disabled,
      open: open
    });
  }

  renderCalendar() {
    const {
      allowSingleDateSelection,
      minDate,
      maxDate,
      calendar,
      navPrevIcon,
      navNextIcon,
      presetsComponent,
      presets,
      presetsIcon,
      buttons,
      clearText,
      applyText
    } = this.props;
    const {
      selectedStartDate,
      selectedEndDate
    } = this.state;
    return cloneElement(calendar, {
      startDate: selectedStartDate,
      endDate: selectedEndDate,
      onDatesChange: this.handleCalendarDatesChange,
      onApply: this.handleCalendarApply,
      allowSingleDateSelection,
      minDate,
      maxDate,
      presetsComponent,
      presets,
      presetsIcon,
      buttons,
      navPrevIcon,
      navNextIcon,
      clearText,
      applyText
    });
  }

  render() {
    const {
      disabled
    } = this.props;
    const {
      open
    } = this.state;
    return React.createElement("div", {
      className: this.getCssClasses(),
      __source: {
        fileName: _jsxFileName,
        lineNumber: 241
      },
      __self: this
    }, this.renderInput(), !disabled ? React.createElement(FadeIn, {
      active: open,
      className: "relative z-2",
      __source: {
        fileName: _jsxFileName,
        lineNumber: 244
      },
      __self: this
    }, React.createElement(Popup, Object.assign({
      visible: open,
      onOutsideClick: this.handlePopupClose,
      onEscapeKeyDown: this.handlePopupClose
    }, this.getAnchorDirectionProps(), {
      __source: {
        fileName: _jsxFileName,
        lineNumber: 245
      },
      __self: this
    }), React.createElement("div", {
      ref: this._containerRef,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 246
      },
      __self: this
    }, this.renderCalendar()))) : null);
  }

}

_defineProperty(DateRangePicker, "propTypes", {
  startDate: object,
  endDate: object,
  defaultStartDate: object,
  defaultEndDate: object,
  onDatesChange: func.isRequired,
  onVisibilityChange: func,
  allowSingleDateSelection: bool,
  minDate: object,
  maxDate: object,
  input: node,
  inputIcon: node,
  inputClearIcon: node,
  placeholder: string,
  rangeFormat: string,
  dateFormat: string,
  anchorDirection: oneOf([ANCHOR_LEFT, ANCHOR_RIGHT]),
  calendar: node,
  navPrevIcon: node,
  navNextIcon: node,
  presetsComponent: node,
  presets: arrayOf(shape(PRESET_SHAPE)),
  presetsIcon: node,
  buttons: node,
  clearText: string,
  applyText: string,
  defaultOpen: bool,
  open: bool,
  disabled: bool,
  className: string
});

_defineProperty(DateRangePicker, "defaultProps", {
  allowSingleDateSelection: false,
  input: React.createElement(DateRangePickerInput, {
    __source: {
      fileName: _jsxFileName,
      lineNumber: 53
    },
    __self: this
  }),
  inputIcon: React.createElement(InputCalendarIcon, {
    __source: {
      fileName: _jsxFileName,
      lineNumber: 54
    },
    __self: this
  }),
  inputClearIcon: React.createElement(ClearIcon, {
    className: "h3 w3",
    __source: {
      fileName: _jsxFileName,
      lineNumber: 55
    },
    __self: this
  }),
  placeholder: "Pick a date",
  rangeFormat: "{startDate} - {endDate}",
  dateFormat: "MMM Do YYYY",
  anchorDirection: ANCHOR_LEFT,
  calendar: React.createElement(DateRangePickerCalendar, {
    __source: {
      fileName: _jsxFileName,
      lineNumber: 60
    },
    __self: this
  }),
  navPrevIcon: React.createElement(ArrowIcon, {
    className: "w4 h4 rotate-180 fill-cloud-500",
    __source: {
      fileName: _jsxFileName,
      lineNumber: 61
    },
    __self: this
  }),
  navNextIcon: React.createElement(ArrowIcon, {
    className: "w4 h4 fill-cloud-500",
    __source: {
      fileName: _jsxFileName,
      lineNumber: 62
    },
    __self: this
  }),
  presetsComponent: React.createElement(DateRangePickerPresets, {
    __source: {
      fileName: _jsxFileName,
      lineNumber: 63
    },
    __self: this
  }),
  presets: [],
  presetsIcon: React.createElement(PresetsCalendarIcon, {
    className: "w8 h8 fill-cloud-500",
    __source: {
      fileName: _jsxFileName,
      lineNumber: 65
    },
    __self: this
  }),
  buttons: React.createElement(DateRangePickerButtons, {
    __source: {
      fileName: _jsxFileName,
      lineNumber: 66
    },
    __self: this
  }),
  clearText: "Clear",
  applyText: "Apply",
  disabled: false
});

_defineProperty(DateRangePicker, "autoControlledProps", ["startDate", "endDate", "open"]);

_defineProperty(DateRangePicker, "Input", DateRangePickerInput);

_defineProperty(DateRangePicker, "Calendar", DateRangePickerCalendar);

_defineProperty(DateRangePicker, "Presets", DateRangePickerPresets);

_defineProperty(DateRangePicker, "Buttons", DateRangePickerButtons);