import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
var _jsxFileName = "C:\\Dev\\20_gsoft\\sg-orbit\\packages\\react-components\\components\\search-input\\src\\search-input.jsx";
import React from "react";
import { AutoControlledPureComponent, KEYS, getAutoControlledStateFromProps } from "@orbit-ui/react-components-shared";
import { RESULT_SHAPE } from "./results";
import { SearchInputController } from "./search-input-controller";
import { arrayOf, bool, func, number, shape, string } from "prop-types";
import { isNil } from "lodash";
export function startsWithSearch(items, query) {
  return items.filter(x => x.text.toUpperCase().startsWith(query.toUpperCase()));
}
export class SearchInput extends AutoControlledPureComponent {
  constructor() {
    super(...arguments);

    _defineProperty(this, "state", {
      open: false,
      visibleResults: []
    });

    _defineProperty(this, "handleSearch", (event, query) => {
      const {
        results,
        onSearch,
        minCharacters
      } = this.props;

      if (query.length >= minCharacters) {
        const newResults = onSearch(results, query, this.props);
        this.setState({
          visibleResults: newResults
        });
        this.open(event);
      } else {
        this.setState({
          visibleResults: []
        });
        this.close(event);
      }
    });

    _defineProperty(this, "handleValueChange", (event, value) => {
      const {
        onValueChange
      } = this.props;
      this.close(event);

      if (isNil(value)) {
        this.handleClear(event);
      }

      onValueChange(event, value, this.props);
    });

    _defineProperty(this, "handleClear", () => {
      const {
        results
      } = this.props;
      this.setState({
        visibleResults: results
      });
    });

    _defineProperty(this, "handleBlur", event => {
      const {
        onBlur
      } = this.props;
      this.close(event);

      if (!isNil(onBlur)) {
        onBlur(event, this.props);
      }
    });

    _defineProperty(this, "handleKeyDown", event => {
      const {
        onKeyDown
      } = this.props;

      if (event.keyCode === KEYS.esc) {
        this.close(event);
      }

      if (!isNil(onKeyDown)) {
        onKeyDown(event, this.props);
      }
    });
  }

  static getDerivedStateFromProps(props, state) {
    return getAutoControlledStateFromProps(props, state, SearchInput.autoControlledProps);
  } // TODO: memoizing search result could greatly improved the performance of this component:
  //  - The shallow comparison done by search-input-controller would not force a re-render when this is the same results


  open(event) {
    const {
      onVisibilityChange
    } = this.props;
    this.trySetAutoControlledStateValue({
      open: true
    });

    if (!isNil(onVisibilityChange)) {
      onVisibilityChange(event, true, this.props);
    }
  }

  close() {
    const {
      onVisibilityChange
    } = this.props;
    this.trySetAutoControlledStateValue({
      open: false
    });

    if (!isNil(onVisibilityChange)) {
      onVisibilityChange(event, false, this.props);
    }
  }

  render() {
    const {
      value,
      defaultValue,
      resultRenderer,
      clearOnSelect,
      noResultsMessage,
      minCharacters,
      debounceDelay,
      placeholder,
      disabled,
      autofocus,
      className
    } = this.props;
    const {
      open,
      visibleResults
    } = this.state;
    return React.createElement(SearchInputController, {
      open: open,
      results: visibleResults,
      value: value,
      defaultValue: defaultValue,
      onValueChange: this.handleValueChange,
      onSearch: this.handleSearch,
      onBlur: this.handleBlur,
      onKeyDown: this.handleKeyDown,
      resultRenderer: resultRenderer,
      clearOnSelect: clearOnSelect,
      noResultsMessage: noResultsMessage,
      minCharacters: minCharacters,
      debounceDelay: debounceDelay,
      placeholder: placeholder,
      disabled: disabled,
      autofocus: autofocus,
      className: className,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 132
      },
      __self: this
    });
  }

}

_defineProperty(SearchInput, "propTypes", {
  results: arrayOf(shape(RESULT_SHAPE)).isRequired,
  value: string,
  defaultValue: string,
  onValueChange: func.isRequired,
  onVisibilityChange: func,
  onSearch: func,
  onBlur: func,
  resultRenderer: func,
  clearOnSelect: bool,
  noResultsMessage: string,
  debounceDelay: number,
  minCharacters: number,
  placeholder: string,
  defaultOpen: bool,
  open: bool,
  disabled: bool,
  autofocus: bool,
  className: string
});

_defineProperty(SearchInput, "defaultProps", {
  onSearch: startsWithSearch,
  minCharacters: 1,
  debounceDelay: 200,
  autofocus: false
});

_defineProperty(SearchInput, "autoControlledProps", ["open"]);